"""Setup file for fedmsg-rabbitmq-serializer"""

import sys

from setuptools import setup, find_packages


def get_description():
    with open('README.rst', 'r') as f:
        return ''.join(f.readlines()[2:])


def get_requirements(filename='requirements.txt'):
    """
    Get the contents of a file listing the requirements.

    :param filename: path to a requirements file
    :type  filename: str

    :returns: the list of requirements
    :return type: list
    """
    with open(filename) as f:
        return [
            line.rstrip().split('#')[0]
            for line in f.readlines()
            if not line.startswith('#')
        ]


requires = get_requirements()
if sys.version_info[0] == 2 and sys.version_info[1] <= 6:
    requires.append("ordereddict")

setup(
    name='fedmsg-rabbitmq-serializer',
    version='0.0.1',
    description='Small utility to serialize fedmsgs into rabbitmq worker queue',
    long_description=get_description(),
    author='Fedora Infrastructure Team',
    author_email='infrastructure@lists.fedoraproject.org',
    url="https://pagure.io/fedmsg-rabbitmq-serializer",
    download_url="https://pypi.python.org/pypi/fedmsg-rabbitmq-serializer/",
    license='LGPLv2+',
    install_requires=requires,
    zip_safe=False,
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: GNU Lesser General Public License v2 or later (LGPLv2+)',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
    ],
    entry_points={
        'moksha.consumer': [
            "fedmsg_rabbitmq_serializer_consumer = fedmsg_rabbitmq_serializer.consumer:RabbitMQSerializerConsumer",
        ],
    },
)
